@@ -1,25 +1,9 @@
 /*
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2007 Bruno Virlet <bruno@virlet.org>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Bruno Virlet <bruno@virlet.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "timelabels.h"
 #include "agenda.h"
@@ -31,7 +15,6 @@
 
 #include <KLocalizedString>
 
-#include <QFrame>
 #include <QHelpEvent>
 #include <QIcon>
 #include <QMenu>
@@ -51,7 +34,7 @@ TimeLabels::TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent,
 
     mCellHeight = mTimeLabelsZone->preferences()->hourSize() * 4;
 
-    setBackgroundRole(QPalette::Background);
+    setBackgroundRole(QPalette::Window);
 
     mMousePos = new QFrame(this);
     mMousePos->setLineWidth(1);
@@ -65,7 +48,7 @@ TimeLabels::TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent,
     updateConfig();
 }
 
-void TimeLabels::mousePosChanged(const QPoint &pos)
+void TimeLabels::mousePosChanged(QPoint pos)
 {
     colorMousePos();
     mMousePos->move(0, pos.y());
@@ -89,9 +72,9 @@ void TimeLabels::hideMousePos()
 void TimeLabels::colorMousePos()
 {
     QPalette pal;
-    pal.setColor(QPalette::Window,  // for Oxygen
+    pal.setColor(QPalette::Window, // for Oxygen
                  mTimeLabelsZone->preferences()->agendaMarcusBainsLineLineColor());
-    pal.setColor(QPalette::WindowText,  // for Plastique
+    pal.setColor(QPalette::WindowText, // for Plastique
                  mTimeLabelsZone->preferences()->agendaMarcusBainsLineLineColor());
     mMousePos->setPalette(pal);
 }
@@ -128,7 +111,7 @@ void TimeLabels::updateConfig()
     if (use12Clock()) {
         test = QStringLiteral("12");
     }
-    mMiniWidth = fontMetrics().width(test);
+    mMiniWidth = fontMetrics().boundingRect(test).width();
     if (use12Clock()) {
         test = QStringLiteral("pm");
     } else {
@@ -137,7 +120,7 @@ void TimeLabels::updateConfig()
     QFont sFont = font();
     sFont.setPointSize(sFont.pointSize() / 2);
     QFontMetrics fmS(sFont);
-    mMiniWidth += fmS.width(test) + frameWidth() * 2 + 4;
+    mMiniWidth += fmS.boundingRect(test).width() + frameWidth() * 2 + 4;
 
     /** Can happen if all resources are disabled */
     if (!mAgenda) {
@@ -173,17 +156,14 @@ void TimeLabels::setAgenda(Agenda *agenda)
 
 int TimeLabels::yposToCell(const int ypos) const
 {
-    const KCalCore::DateList datelist = mAgenda->dateList();
+    const KCalendarCore::DateList datelist = mAgenda->dateList();
     if (datelist.isEmpty()) {
         return 0;
     }
 
     const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
-    const int beginning   // the hour we start drawing with
-        = !mTimezone.isValid()
-          ? 0
-          : (mTimezone.offsetFromUtc(firstDay)
-             -mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+    const int beginning // the hour we start drawing with
+        = !mTimezone.isValid() ? 0 : (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
     return static_cast<int>(ypos / mCellHeight) + beginning;
 }
@@ -215,7 +195,7 @@ int TimeLabels::cellToHour(const int cell) const
 
 QString TimeLabels::cellToSuffix(const int cell) const
 {
-    //TODO: rewrite this using QTime's time formats. "am/pm" doesn't make sense
+    // TODO: rewrite this using QTime's time formats. "am/pm" doesn't make sense
     // in some locale's
     QString suffix;
     if (use12Clock()) {
@@ -236,7 +216,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     if (!mAgenda) {
         return;
     }
-    const KCalCore::DateList datelist = mAgenda->dateList();
+    const KCalendarCore::DateList datelist = mAgenda->dateList();
     if (datelist.isEmpty()) {
         return;
     }
@@ -249,11 +229,8 @@ void TimeLabels::paintEvent(QPaintEvent *)
     const int cy = -y(); // y() returns a negative value.
 
     const auto firstDay = QDateTime(datelist.first(), QTime(0, 0, 0), Qt::LocalTime).toUTC();
-    const int beginning
-        = !mTimezone.isValid()
-          ? 0
-          : (mTimezone.offsetFromUtc(firstDay)
-             -mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
+    const int beginning =
+        !mTimezone.isValid() ? 0 : (mTimezone.offsetFromUtc(firstDay) - mTimeLabelsZone->preferences()->timeZone().offsetFromUtc(firstDay)) / 3600;
 
     // bug:  the parameters cx and cw are the areas that need to be
     //       redrawn, not the area of the widget.  unfortunately, this
@@ -272,7 +249,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     QFont hourFont = mTimeLabelsZone->preferences()->agendaTimeLabelsFont();
     p.setFont(font());
 
-    //TODO: rewrite this using QTime's time formats. "am/pm" doesn't make sense
+    // TODO: rewrite this using QTime's time formats. "am/pm" doesn't make sense
     // in some locale's
     QString suffix;
     if (!use12Clock()) {
@@ -285,7 +262,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
     if (timeHeight > mCellHeight) {
         timeHeight = static_cast<int>(mCellHeight - 1);
         int pointS = hourFont.pointSize();
-        while (pointS > 4) {   // TODO: use smallestReadableFont() when added to kdelibs
+        while (pointS > 4) { // TODO: use smallestReadableFont() when added to kdelibs
             hourFont.setPointSize(pointS);
             fm = QFontMetrics(hourFont);
             if (fm.ascent() < mCellHeight) {
@@ -296,15 +273,15 @@ void TimeLabels::paintEvent(QPaintEvent *)
         fm = QFontMetrics(hourFont);
         timeHeight = fm.ascent();
     }
-    //timeHeight -= (timeHeight/4-2);
+    // timeHeight -= (timeHeight/4-2);
     QFont suffixFont = hourFont;
     suffixFont.setPointSize(suffixFont.pointSize() / 2);
     QFontMetrics fmS(suffixFont);
     const int startW = cw - frameWidth() - 2;
-    const int tw2 = fmS.width(suffix);
+    const int tw2 = fmS.boundingRect(suffix).width();
     const int divTimeHeight = (timeHeight - 1) / 2 - 1;
-    //testline
-    //p->drawLine(0,0,0,contentsHeight());
+    // testline
+    // p->drawLine(0,0,0,contentsHeight());
     while (y < cy + ch + mCellHeight) {
         QColor lineColor, textColor;
         textColor = palette().color(QPalette::WindowText);
@@ -324,7 +301,7 @@ void TimeLabels::paintEvent(QPaintEvent *)
 
         // draw the time label
         p.setPen(textColor);
-        const int timeWidth = fm.width(hour);
+        const int timeWidth = fm.boundingRect(hour).width();
         int offset = startW - timeWidth - tw2 - 1;
         p.setFont(hourFont);
         p.drawText(offset, static_cast<int>(y + timeHeight), hour);
@@ -340,21 +317,17 @@ void TimeLabels::paintEvent(QPaintEvent *)
 
 QSize TimeLabels::sizeHint() const
 {
-    return QSize(mMiniWidth, mRows * mCellHeight);
+    return {mMiniWidth, static_cast<int>(mRows * mCellHeight)};
 }
 
 void TimeLabels::contextMenuEvent(QContextMenuEvent *event)
 {
-    Q_UNUSED(event);
+    Q_UNUSED(event)
 
     QMenu popup(this);
-    QAction *editTimeZones = popup.addAction(QIcon::fromTheme(QStringLiteral("document-properties")),
-                                             i18n("&Add Timezones..."));
-    QAction *removeTimeZone = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")),
-                                              i18n("&Remove Timezone %1", i18n(mTimezone.id().constData())));
-    if (!mTimezone.isValid()
-        || !mTimeLabelsZone->preferences()->timeScaleTimezones().count()
-        || mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
+    QAction *editTimeZones = popup.addAction(QIcon::fromTheme(QStringLiteral("document-properties")), i18n("&Add Timezones..."));
+    QAction *removeTimeZone = popup.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("&Remove Timezone %1", i18n(mTimezone.id().constData())));
+    if (!mTimezone.isValid() || !mTimeLabelsZone->preferences()->timeScaleTimezones().count() || mTimezone == mTimeLabelsZone->preferences()->timeZone()) {
         removeTimeZone->setEnabled(false);
     }
 
@@ -393,35 +366,33 @@ QString TimeLabels::headerToolTip() const
 
     toolTip += QLatin1String("<qt>");
     toolTip += i18nc("title for timezone info, the timezone id and utc offset",
-                     "<b>%1 (%2)</b>", i18n(mTimezone.id().constData()),
+                     "<b>%1 (%2)</b>",
+                     i18n(mTimezone.id().constData()),
                      KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
     toolTip += QLatin1String("<hr>");
-    toolTip += i18nc("heading for timezone display name",
-                     "<i>Name:</i> %1", mTimezone.displayName(now, QTimeZone::LongName));
+    toolTip += i18nc("heading for timezone display name", "<i>Name:</i> %1", mTimezone.displayName(now, QTimeZone::LongName));
     toolTip += QLatin1String("<br/>");
 
     if (mTimezone.country() != QLocale::AnyCountry) {
-        toolTip += i18nc("heading for timezone country",
-                         "<i>Country:</i> %1", QLocale::countryToString(mTimezone.country()));
+        toolTip += i18nc("heading for timezone country", "<i>Country:</i> %1", QLocale::countryToString(mTimezone.country()));
         toolTip += QLatin1String("<br/>");
     }
 
     auto abbreviations = QStringLiteral("&nbsp;");
-    foreach (const auto &transition, mTimezone.transitions(now, now.addYears(1))) {
+    const auto lst = mTimezone.transitions(now, now.addYears(1));
+    for (const auto &transition : lst) {
         abbreviations += transition.abbreviation;
         abbreviations += QLatin1String(",&nbsp;");
     }
     abbreviations.chop(7);
     if (!abbreviations.isEmpty()) {
-        toolTip += i18nc("heading for comma-separated list of timezone abbreviations",
-                         "<i>Abbreviations:</i>");
+        toolTip += i18nc("heading for comma-separated list of timezone abbreviations", "<i>Abbreviations:</i>");
         toolTip += abbreviations;
         toolTip += QLatin1String("<br/>");
     }
     const QString timeZoneComment(mTimezone.comment());
     if (!timeZoneComment.isEmpty()) {
-        toolTip += i18nc("heading for the timezone comment",
-                         "<i>Comment:</i> %1", timeZoneComment);
+        toolTip += i18nc("heading for the timezone comment", "<i>Comment:</i> %1", timeZoneComment);
     }
     toolTip += QLatin1String("</qt>");
 
@@ -431,14 +402,15 @@ QString TimeLabels::headerToolTip() const
 bool TimeLabels::event(QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
-        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        auto helpEvent = static_cast<QHelpEvent *>(event);
         const int cell = yposToCell(helpEvent->pos().y());
 
         QString toolTip;
         toolTip += QLatin1String("<qt>");
         toolTip += i18nc("[hour of the day][am/pm/00] [timezone id (timezone-offset)]",
                          "%1%2<br/>%3 (%4)",
-                         cellToHour(cell), cellToSuffix(cell),
+                         cellToHour(cell),
+                         cellToSuffix(cell),
                          i18n(mTimezone.id().constData()),
                          KCalUtils::Stringify::tzUTCOffsetStr(mTimezone));
         toolTip += QLatin1String("</qt>");
