@@ -1,26 +1,9 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "todoviewview.h"
@@ -36,8 +19,6 @@
 
 TodoViewView::TodoViewView(QWidget *parent)
     : QTreeView(parent)
-    , mHeaderPopup(nullptr)
-    , mIgnoreNextMouseRelease(false)
 {
     header()->installEventFilter(this);
     setAlternatingRowColors(true);
@@ -48,23 +29,21 @@ TodoViewView::TodoViewView(QWidget *parent)
 
 bool TodoViewView::isEditing(const QModelIndex &index) const
 {
-    return state() & QAbstractItemView::EditingState
-           && currentIndex() == index;
+    return state() & QAbstractItemView::EditingState && currentIndex() == index;
 }
 
 bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
 {
-    Q_UNUSED(watched);
+    Q_UNUSED(watched)
     if (event->type() == QEvent::ContextMenu) {
-        QContextMenuEvent *e = static_cast<QContextMenuEvent *>(event);
+        auto e = static_cast<QContextMenuEvent *>(event);
 
         if (!mHeaderPopup) {
             mHeaderPopup = new QMenu(this);
             mHeaderPopup->setTitle(i18n("View Columns"));
             // First entry can't be disabled
             for (int i = 1; i < model()->columnCount(); ++i) {
-                QAction *tmp
-                    = mHeaderPopup->addAction(model()->headerData(i, Qt::Horizontal).toString());
+                QAction *tmp = mHeaderPopup->addAction(model()->headerData(i, Qt::Horizontal).toString());
                 tmp->setData(QVariant(i));
                 tmp->setCheckable(true);
                 mColumnActions << tmp;
@@ -73,7 +52,7 @@ bool TodoViewView::eventFilter(QObject *watched, QEvent *event)
             connect(mHeaderPopup, &QMenu::triggered, this, &TodoViewView::toggleColumnHidden);
         }
 
-        for (QAction *action : qAsConst(mColumnActions)) {
+        for (QAction *action : std::as_const(mColumnActions)) {
             int column = action->data().toInt();
             action->setChecked(!isColumnHidden(column));
         }
@@ -104,11 +83,9 @@ QModelIndex TodoViewView::moveCursor(CursorAction cursorAction, Qt::KeyboardModi
     }
 
     switch (cursorAction) {
-    case MoveNext:
-    {
+    case MoveNext: {
         // try to find an editable item right of the current one
-        QModelIndex tmp = getNextEditableIndex(
-            current.sibling(current.row(), current.column() + 1), 1);
+        QModelIndex tmp = getNextEditableIndex(current.sibling(current.row(), current.column() + 1), 1);
         if (tmp.isValid()) {
             return tmp;
         }
@@ -137,13 +114,11 @@ QModelIndex TodoViewView::moveCursor(CursorAction cursorAction, Qt::KeyboardModi
                 return tmp;
             }
         }
-        return QModelIndex();
+        return {};
     }
-    case MovePrevious:
-    {
+    case MovePrevious: {
         // try to find an editable item left of the current one
-        QModelIndex tmp = getNextEditableIndex(
-            current.sibling(current.row(), current.column() - 1), -1);
+        QModelIndex tmp = getNextEditableIndex(current.sibling(current.row(), current.column() - 1), -1);
         if (tmp.isValid()) {
             return tmp;
         }
@@ -189,7 +164,7 @@ QModelIndex TodoViewView::getNextEditableIndex(const QModelIndex &cur, int inc)
             return tmp;
         }
     }
-    return QModelIndex();
+    return {};
 }
 
 void TodoViewView::mouseReleaseEvent(QMouseEvent *event)
